﻿#region License Information

/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */

#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Core;

namespace HeuristicLab.Problems.DataAnalysis.Symbolic {
  public sealed class EnumerableItem<T> : Item, IEnumerable<T> where T : struct {

    private readonly IEnumerable<T> enumerable;
    public IEnumerable<T> Enumerable {
      get { return enumerable; }
    }

    private EnumerableItem(EnumerableItem<T> original, Cloner cloner)
      : base(original, cloner) {
      enumerable = original.enumerable;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new EnumerableItem<T>(this, cloner);
    }

    public EnumerableItem(IEnumerable<T> enumerable) {
      this.enumerable = enumerable;
    }

    #region IEnumerable<T> Members
    public IEnumerator<T> GetEnumerator() {
      return enumerable.GetEnumerator();
    }
    #endregion

    #region IEnumerable Members
    System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator() {
      return enumerable.GetEnumerator();
    }
    #endregion
  }
}
